import { SGraphyItem, SMouseEvent } from '@sybotan-web/graphy'
import { SRect, SSize } from "@sybotan-web/base";
import { SPen, SPainter, SColor } from "@sybotan-web/draw";

/**
 * 图形Item类  todo
 *
 */
export class SGraphyImgItem extends SGraphyItem {
	width: number = 0;
	height: number = 0;
	url: string = '';
	id: string;
	X: number;
	Y: number;
	downUrl: string;

	/**
	 * 构造函数
	 * 
	 * @param width    图片宽度
	 * @param height   图片高度
	 * @param url      图片url
	 * @param id       point的Id
	 * @param X        图片向x轴的偏移量
	 * @param Y        图片向y轴的偏移量
	 * @param downUrl  图片按下时的url
	 * @param parent   指向父元素
	 */
	constructor(
		parent: SGraphyItem | null,
		X: number,
		Y: number,
		width: number,
		height: number,
		url: string,
		id: string,
		downUrl: string = ''
	) {
		super(parent);
		this.width = width;
		this.height = height;
		this.url = url;
		this.id = id;
		this.X = X;
		this.Y = Y;
		this.downUrl = downUrl;
	} // Constructor()

	/**
	 * Item对象边界区域
	 * 
	 * @return SRect
	 */
	boundingRect(): SRect {
		return new SRect(
			this.X,
			this.Y,
			this.width,
			this.height
		);
	} // Function boundingRect()
	onClick(event: SMouseEvent): boolean {
		this.$emit('click', { item: this, event: event });
		return true;
	} // Function onClick()
	/**
  * 鼠标双击事件
  *
  * @param   event   保存事件参数
  * @return  boolean
  */
	onDoubleClick(event: SMouseEvent): boolean {
		this.$emit('doubleClick', { item: this, event: event });
		return true;
	}
	/**
  * 鼠标按下事件
  *
  * @param   event   保存事件参数
  * @return  boolean
  */
	onMouseDown(event: SMouseEvent): boolean {
		this.$emit('mouseDown', { item: this, event: event });
		return true;
	} // Function onMouseDown()

	/**
	 * 鼠标移动事件
	 *
	 * @param   event   保存事件参数
	 * @return  boolean
	 */
	onMouseMove(event: SMouseEvent): boolean {
		this.$emit('mouseMove', { item: this, event: event });
		return true;
	} // Function onMouseMove()

	/**
	 * 释放鼠标事件
	 *
	 * @param   event   保存事件参数
	 * @return  boolean
	 */
	onMouseUp(event: SMouseEvent): boolean {
		this.$emit('mouseUp', { item: this, event: event });
		return true;
	}
	/**
	 * Item绘制操作
	 *
	 * @param   painter       painter对象
	 * @param   rect          绘制区域
	 */
	onDraw(painter: SPainter, rect?: SRect): void {
		painter.pen.color = new SColor('#409EFF');
		painter.brush.color = new SColor('#409EFF');
		painter.pen.lineWidth = 100;
		painter.drawCircle(this.X + this.width / 2, this.Y + this.height / 2, this.width / 2);
	}
} // Class SGraphyImgItem
